Learn R Programming

multisensi (version 2.2-1)

basis.ACP: A function to decompose multivariate data by principal components analysis (PCA)

Description

The basis.ACP function decomposes a multivariate data set according to principal components analysis.

Usage

basis.ACP(simuls, basis.args = list())

Value

H

a data.frame of size N x T, containing the coefficients of the PCA decomposition. It is equal to the x output of function prcomp.

L

a matrix of size T x T. It contains the eigenvectors of the PCA decomposition.

call.info

list with the element reduction="pca"

Arguments

simuls

a data.frame of size N x T, typically a set of N simulation outputs of length T.

basis.args

an empty list of arguments for the PCA decomposition.

Details

This function uses prcomp.

See Also

Examples

Run this code
data(biomasseY)
res <- basis.ACP(biomasseY)

Run the code above in your browser using DataLab