View source: R/basis.bsplines.r
| basis.bsplines | R Documentation |
The basis.bsplines function decomposes a multivariate data set on a B-spline basis defined by its knots and mdegree parameters.
basis.bsplines(simuls, basis.args = list(knots = 5, mdegree = 3))
simuls |
a data.frame of size |
basis.args |
a list of arguments for the B-spline decomposition. The |
The optional x.coord element of the list in basis.args can
be used to specify the support of the B-spline decomposition, if
different from 1:T. It must be a vector of length T.
H |
a data.frame of size |
L |
a matrix of size |
call.info |
list with the element |
bspline, sesBsplinesNORM
data(biomasseY)
res <- basis.bsplines(biomasseY,basis.args=list(knots=7,mdegree=3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.