View source: R/basis.osplines.r
| basis.osplines | R Documentation |
The basis.osplines function decomposes a multivariate data set on an orthogonalised B-spline (or O-spline) basis defined by its knots and mdegree parameters.
basis.osplines(simuls, basis.args = list(knots = 5, mdegree = 3))
simuls |
a data.frame of size |
basis.args |
a list of arguments for the O-spline decomposition. The |
The optional x.coord element of the list in basis.args can be used to specify the support of the O-spline decomposition, if different from 1:T. It must be a vector of length T.
H |
a data.frame of size |
L |
a matrix of size |
call.info |
list with the element |
bspline,
sesBsplinesORTHONORM
data(biomasseY)
res <- basis.osplines(biomasseY,basis.args=list(knots=7,mdegree=3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.