basis.poly: A function to decompose multivariate data on a polynomial basis
Description
The basis.poly function decomposes a multivariate data set on a polynomial basis.
Usage
basis.poly(simuls, basis.args = list(degree = 3))
Value
H
a data.frame of size N x (d+1), where d is the degree of the polynomial decomposition. It contains the coefficients of the decomposition for each row of the simuls data.frame.
L
a matrix of size T x (d+1). It contains the vectors of the polynomial basis.
call.info
list with the element reduction="polynomial"
Arguments
simuls
a data.frame of size N x T, typically a set of N simulation outputs of length T.
basis.args
a list of arguments for the polynomial decomposition. The degree argument is the maximum degree of the polynomial basis. For the optional x.coord argument, see the Details section.
Details
This function uses poly. The optional x.coord element of the list in basis.args can be used to specify the support of the polynomial decomposition, if different from 1:T. It must be a vector of length T.