graph.bar: Sensitivity index bar plot

View source: R/graph.bar.r

graph.barR Documentation

Sensitivity index bar plot

Description

A function that plots sensitivity indices by a bar graph

Usage

graph.bar(x, col = 1, nb.plot = 15, xmax = NULL,
          beside = TRUE, xlab = NULL, ...)

Arguments

x

an object of class gsi or dynsi

col

the column number of GSI to represent in the bar graph

nb.plot

number of input factors to be considered

xmax

a user-defined maximal x value (x\leq 1) in all the bar graphs that show sensitivity indices; or NULL if the user wants to keep default values

beside

if TRUE, the main and total sensitivity indices are represented by two bars; if FALSE, they are represented by the same bar

xlab

a label for the x axis

...

graphical parameters


multisensi documentation built on Aug. 20, 2026, 1:08 a.m.