| predict.gsi | R Documentation |
The function predict.gsi generates predicted multivariate output for user-specified combinations of levels of the input factors.
## S3 method for class 'gsi'
predict(object, newdata, ...)
object |
Object of class gsi. |
newdata |
An optional data frame in which to look for variables with which to predict. If omitted, the fitted values are used. need to be same factors and levels as for obtained the gsi object. |
... |
others parameters |
Only available if the gsi object was obtained with analysis.anoasg and analysis.args$keep.outputs=TRUE.
a data.frame of predicted values for newdata
gsi, multisensi, analysis.anoasg
data(biomasseX)
data(biomasseY)
x=multisensi(design=biomasseX,model=biomasseY,basis=basis.ACP,
analysis=analysis.anoasg,
analysis.args=list(formula=2, keep.outputs=TRUE))
newdata=as.data.frame(apply(biomasseX,2,unique))
predict(x,newdata)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.