| quality | R Documentation |
Function that computes the sensitivity quality after making some assumptions about the number of PCs and the number of interactions
quality(echsimul, echsimul.app)
echsimul |
model outputs |
echsimul.app |
Predicted model output |
A list with the following components:
mean of the residuals
biais
R-square
This is essentially an internal function for the multisensi package
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.