| simulmodel | R Documentation |
Function that simulates the model outputs
simulmodel(model, plan, nomFic = NULL, verbose = FALSE, ...)
model |
name of R-function |
plan |
data frame of input design |
nomFic |
name of file that contains the model function |
verbose |
verbose |
... |
possible fixed parameters of the R-function |
The model function must be a R-function. Models defined as functions
will be called once with an expression of the form y <- f(X) where X is
a vector containing a combination of levels of the input factors, and y
is the output vector of length q, where q is the number of output
variables
data frame of model outputs
This is essentially an internal function for the multisensi package
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.