| graph.bar | R Documentation |
A function that plots sensitivity indices by a bar graph
graph.bar(x, col = 1, nb.plot = 15, xmax = NULL,
beside = TRUE, xlab = NULL, ...)
x |
an object of class gsi or dynsi |
col |
the column number of GSI to represent in the bar graph |
nb.plot |
number of input factors to be considered |
xmax |
a user-defined maximal |
beside |
if TRUE, the main and total sensitivity indices are represented by two bars; if FALSE, they are represented by the same bar |
xlab |
a label for the x axis |
... |
graphical parameters |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.